==> ajh-facade-1.0.5-20210919.071447-47-sources.jar: com/bizvane/ajhfacade/rpc/OdersRpcService.java <==
package com.bizvane.ajhfacade.rpc;
import com.bizvane.ajhfacade.models.po.Comments;
import com.bizvane.ajhfacade.models.po.Orders;
import com.bizvane.ajhfacade.models.po.Project;
import com.bizvane.ajhfacade.vo.InstallVO;
import com.bizvane.ajhfacade.vo.OverBookingVO;
import com.bizvane.ajhfacade.vo.PurchasedProductsVO;
import com.bizvane.utils.responseinfo.ResponseData;
import com.github.pagehelper.PageInfo;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Service;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import java.util.List;
@FeignClient(value = "${feign.client.ajh.name}", path = "${feign.client.ajh.path}/ordersRpc")
public interface OdersRpcService {

     @RequestMapping(value = "/addOrder", method = RequestMethod.POST)
     ResponseData addOrder(@RequestBody Orders orders);

     @RequestMapping(value = "/updateState", method = RequestMethod.POST)
     ResponseData updateState(@RequestBody Orders orders);

     @RequestMapping(value = "/getOrdersListRpc", method = RequestMethod.POST)
     ResponseData<PageInfo> selectAftermarket(@RequestBody InstallVO installVO);

     @RequestMapping(value = "/insert", method = RequestMethod.POST)
     ResponseData insert(@RequestBody Comments comments);

     @RequestMapping(value = "/updateCancel", method = RequestMethod.POST)
     ResponseData userCancel(@RequestBody Orders orders);

     @RequestMapping(value = "/querAllByType", method = RequestMethod.GET)
     ResponseData<List<Project>> querAllByType(@RequestParam("projectType") byte projectType);

     @RequestMapping(value = "/selectViewAudit", method = RequestMethod.GET)
     ResponseData selectViewAudit(@RequestParam("id") Integer id);

     @RequestMapping(value = "/selectProducts", method = RequestMethod.POST)
     ResponseData<PageInfo> purchasedProducts(@RequestBody PurchasedProductsVO purchasedProductsVO);

     @RequestMapping(value = "/addplaceOrder", method = RequestMethod.POST)
     ResponseData addplaceOrder(@RequestBody OverBookingVO overBookingVO);

//     @RequestMapping(value = "/getOrderByOrderNo",method = RequestMethod.POST)
//     ResponseData<Orders> getOrderByOrderNo(@RequestParam("orderNo") String orderNo
//          , @Param("sysCompanyId")Long sysCompanyId, @Param("brandId")Integer brandId);

}

==> ajh-facade-1.0.5-20210924.034207-62-sources.jar: com/bizvane/ajhfacade/rpc/OdersRpcService.java <==
package com.bizvane.ajhfacade.rpc;
import com.bizvane.ajhfacade.models.po.Comments;
import com.bizvane.ajhfacade.models.po.Orders;
import com.bizvane.ajhfacade.models.po.Project;
import com.bizvane.ajhfacade.vo.InstallVO;
import com.bizvane.ajhfacade.vo.OverBookingVO;
import com.bizvane.ajhfacade.vo.PurchasedProductsVO;
import com.bizvane.utils.responseinfo.ResponseData;
import com.github.pagehelper.PageInfo;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import java.util.List;
@FeignClient(value = "${feign.client.ajh.name}", path = "${feign.client.ajh.path}/ordersRpc")
public interface OdersRpcService {

     @RequestMapping(value = "/addOrder", method = RequestMethod.POST)
     ResponseData addOrder(@RequestBody Orders orders);

     @RequestMapping(value = "/updateState", method = RequestMethod.POST)
     ResponseData updateState(@RequestBody Orders orders);

     @RequestMapping(value = "/getOrdersListRpc", method = RequestMethod.POST)
     ResponseData<PageInfo> selectAftermarket(@RequestBody InstallVO installVO);

     @RequestMapping(value = "/insert", method = RequestMethod.POST)
     ResponseData insert(@RequestBody Comments comments);

     @RequestMapping(value = "/updateCancel", method = RequestMethod.POST)
     ResponseData userCancel(@RequestBody Orders orders);

     @RequestMapping(value = "/querAllByType", method = RequestMethod.GET)
     ResponseData<List<Project>> querAllByType(@RequestParam("projectType") byte projectType);

     @RequestMapping(value = "/selectViewAudit", method = RequestMethod.GET)
     ResponseData selectViewAudit(@RequestParam("id") Integer id);

     @RequestMapping(value = "/selectProducts", method = RequestMethod.POST)
     ResponseData<PageInfo> purchasedProducts(@RequestBody PurchasedProductsVO purchasedProductsVO);

     @RequestMapping(value = "/addplaceOrder", method = RequestMethod.POST)
     ResponseData addplaceOrder(@RequestBody OverBookingVO overBookingVO);

     @RequestMapping(value = "/synchState", method = RequestMethod.POST)
     ResponseData synchState(@RequestBody Orders orders);


     @RequestMapping(value = "/getOrderByOrderNo",method = RequestMethod.POST)
     ResponseData<Orders> getOrderByOrderNo(@RequestParam("orderNo") String orderNo
          , @RequestParam("sysCompanyId")Long sysCompanyId, @RequestParam("brandId")Integer brandId);

}
